@@ -18,13 +18,6 @@ class AttachedFile(BaseEntity):
         self.size = size
 
 
-class FileReplica(BaseEntity):
-    def __init__(self, did, path, size):
-        self.did = did
-        self.size = size
-        self.path = path
-
-
 class PfnFileReplica(BaseEntity):
     def __init__(self, did, pfn, size):
         self.did = did
